# Vectr Desktop Application

This is a desktop application for Vectr.

# Where to download latest build

[Check out the release.json](http://download.vectr.com/desktop/release.json)

# Prerequisites

```bash
npm install electron-prebuilt@0.33.8 -g # Install **electron** command
npm install # Install all dependencies
gulp # Prepare anything you need
```

Note: If you are going to build windows build from different platform, you should
follow [this](https://github.com/maxogden/electron-packager#building-windows-apps-from-non-windows-platforms)
to install `wine` first to make sure `rcedit` does work when trying to update `vectr.exe`.

## How to build the application

### Create un-signed build
```bash
gulp build #--platform=mac --platform=windows
```

### Create signed build (for Mac OSX for the time being)
```bash
gulp build --platform=mac --sign=7R4WM3WCNR # this is our certificate id, for details, plz check 'Note for codesign' section below
```

## How to run the application

### Shut up, just show me how it works !

If it's your first time to run this project, please run `gulp` first to
make sure everything needed will be generated for later use. After that,
you can use `electron .` to see how it works.

### Or if you want to help developing this application !

great ! after following the previous step, you can use `gulp watch` and
`electron . # with F5 to reload` to see changes !

# Note for debugging

### In Production Build

From **0.1.6**, you can use [Konami code](https://en.wikipedia.org/wiki/Konami_Code)
(↑ ↑ ↓ ↓ ← → ← → B A) to show the debugger tool in production build. Remember,
you need to focus on the document first to make sure it can receieve correct
keydown event from document (Just a simple click !).

After passing Konami code test, you should notice there are two more menu items
showing up from **View** menu. One is for debugging the **Main View** itself,
while another one is for **Web View**. Feel free to choose anyone you want.

One more thing that you should know, if you don't see these two extra menu items,
just type some random key to make sure the buffer is cleaned and try again.

Happy Hacking :)

### In Development Build

You don't need to do anything ! It should always be there under **View** menu.

# Note for environment

Because this is an application and there is no way to use environment variable
like `NODE_ENV` to check the current environment, we use **env.json** as the
reference for difference environment.

P.S. `gulp` will use `development` environment

P.P.S. `gulp build` will use `production` environment

If you are testing the application in local environment, you need to be aware
that it would directly link to your own local server to make sure we won't
mess something up with remote servers. For any customization part, please check
`src/modules/Constant.js` and `src/modules/Core.js`.

# Note for codesign

## For Mac OS X

Right now we already have Deverloper ID certificate from Apple, so our app will
be signed when building. In order to make a valid production build, you need to
install a encrypted certificate and please contact Nick or EJ for that :)

Basically this should be easy to install the certificate, all you need is click
and install. But somehow for old laptops, you may encounter problems that no
matter how you install the certificate, the certificate itself is always expired
with no reason.

For that case, You need to check https://developer.apple.com/support/certificates/expiration/
and renew your **Apple Worldwide Developer Relations Intermediate Certificate** by
downloading a new one.

### How to validate codesigned build

```bash
spctl -a -vvvv Vectr.app
```

If you didn't codesign your build or use the wrong id, you will get something like this :

```
Vectr.app: rejected
source=no usable signature
```

If you successfully codesign your build, you will get something like this :

```
Vectr.app: accepted
source=Developer ID
```

## For Windows

To be continued.

# Note for releasing

If we are going to provide a new release, we need to build them out first and
use lastpass to log in **AWS S3** and check **download.vectr.com** >
**desktop bucket**. What you need to do is to upload releases first and change
the **version** information in **download.vectr.com** > **desktop bucket** >
**release.json**. After that, auto-updating should be working as expected !

# Authors

Vectr Labs
